@@ -61,16 +61,30 @@ try:
     mapper_registry.map_imperatively(Person, tables.people, properties={
         'loans': relationship(Loan, backref='person',
                               cascade='all, delete-orphan'),
-        'loaned_movies_count': column_property(select(
-            [func.count(tables.loans.c.loan_id)],
-            and_(tables.people.c.person_id == tables.loans.c.person_id,
-                 tables.loans.c.return_date is None)).label(
-            'loaned_movies_count'), deferred=True),
-        'returned_movies_count': column_property(select(  # AKA loan history
-            [func.count(tables.loans.c.loan_id)],
-            and_(tables.people.c.person_id == tables.loans.c.person_id,
-                 tables.loans.c.return_date is not None)).label(
-            'returned_movies_count'), deferred=True)
+        'loaned_movies_count': column_property(
+            select(func.count(tables.loans.c.loan_id))
+            .where(
+                and_(
+                    tables.people.c.person_id == tables.loans.c.person_id,
+                    tables.loans.c.return_date.is_(None),
+                )
+            )
+            .correlate_except(tables.loans)
+            .scalar_subquery(),
+            deferred=True,
+        ),
+        'returned_movies_count': column_property(
+            select(func.count(tables.loans.c.loan_id))
+            .where(
+                and_(
+                    tables.people.c.person_id == tables.loans.c.person_id,
+                    tables.loans.c.return_date.is_not(None),
+                )
+            )
+            .correlate_except(tables.loans)
+            .scalar_subquery(),
+            deferred=True,
+        )
         })
     mapper_registry.map_imperatively(MovieLang, tables.movie_lang,
                                      primary_key=[tables.movie_lang.c.ml_id],
@@ -137,17 +151,30 @@ except Exception as ex:
     mapper(Person, tables.people, properties={
         'loans': relation(Loan, backref='person',
                           cascade='all, delete-orphan'),
-        'loaned_movies_count': column_property(select(
-            [func.count(tables.loans.c.loan_id)],
-            and_(tables.people.c.person_id == tables.loans.c.person_id,
-                 tables.loans.c.return_date is None)) \
-                                               .label('loaned_movies_count'),
-                                               deferred=True),
-        'returned_movies_count': column_property(select(  # AKA loan history
-            [func.count(tables.loans.c.loan_id)],
-            and_(tables.people.c.person_id == tables.loans.c.person_id,
-                 tables.loans.c.return_date is not None)) \
-            .label('returned_movies_count'), deferred=True)
+        'loaned_movies_count': column_property(
+            select(func.count(tables.loans.c.loan_id))
+            .where(
+                and_(
+                    tables.people.c.person_id == tables.loans.c.person_id,
+                    tables.loans.c.return_date.is_(None),
+                )
+            )
+            .correlate_except(tables.loans)
+            .scalar_subquery(),
+            deferred=True,
+        ),
+        'returned_movies_count': column_property(
+            select(func.count(tables.loans.c.loan_id))
+            .where(
+                and_(
+                    tables.people.c.person_id == tables.loans.c.person_id,
+                    tables.loans.c.return_date.is_not(None),
+                )
+            )
+            .correlate_except(tables.loans)
+            .scalar_subquery(),
+            deferred=True,
+        ),
         })
     mapper(MovieLang, tables.movie_lang,
            primary_key=[tables.movie_lang.c.ml_id], properties={
