@@ -196,8 +196,7 @@ def con_search_movie(self, where, sort=None):
     else:
         sort_columns = [mt.number]
 
-    statement = select(columns=columns, order_by=sort_columns,
-                       bind=self.db.session.bind)
+    statement = select(*columns).order_by(*sort_columns)
 
     for i in where:
         if i in ('seen', 'loaned'):    # force boolean
@@ -206,11 +205,11 @@ def con_search_movie(self, where, sort=None):
             else:
                 where[i] = True
         if i in ('year', 'number', 'runtime', 'seen', 'loaned', 'rating'):
-            statement.append_whereclause(mt[i] == where[i])
+            statement = statement.where(mt[i] == where[i])
         else:
-            statement.append_whereclause(mt[i].like('%' + where[i] + '%'))
+            statement = statement.where(mt[i].like('%' + where[i] + '%'))
 
-    movies = statement.execute().fetchall()
+    movies = self.db.session.execute(statement).fetchall()
     if not movies:
         print(_("No movie found"))
     else:
