@@ -36,13 +36,13 @@ from logging import getLogger
 
 import gi
 
-# from griffith import log
-log = getLogger('Griffith')
-
 gi.require_version('Gdk', '3.0')
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
 
+# from griffith import log
+log = getLogger('Griffith')
+
 
 try:
     gi.require_version('Gtk', '3.0')
@@ -272,7 +272,7 @@ def clean(text):
 def gdecode(txt, encode):
     try:
         return txt.decode(encode)
-    except:
+    except Exception:
         return txt
 
 # Messages
@@ -445,7 +445,7 @@ def update_preview_cb(file_chooser, preview):
         pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(filename, 128, 128)
         preview.set_from_pixbuf(pixbuf)
         have_preview = True
-    except:
+    except Exception:
         have_preview = False
     file_chooser.set_preview_widget_active(have_preview)
     return
@@ -531,7 +531,7 @@ def get_dependencies():
         version = '.'.join([str(i) for i in Gtk.pygtk_version])
         if Gtk.pygtk_version <= (2, 6, 0):
             version = '-%s' % version
-    except:
+    except Exception:
         version = False
     depend.append({'module': 'gtk',
         'version': version,
@@ -544,7 +544,7 @@ def get_dependencies():
     try:
         import Gtk.glade
         # (version == Gtk.pygtk_version)
-    except:
+    except Exception:
         version = False
     depend.append({'module': 'Gtk.glade',
         'version': version,
@@ -559,7 +559,7 @@ def get_dependencies():
             version = "-%s" % sqlalchemy.__version__
         else:
             version = sqlalchemy.__version__
-    except:
+    except Exception:
         version = False
     depend.append({
         'module': 'sqlalchemy',
@@ -579,7 +579,7 @@ def get_dependencies():
             import pysqlite3.dbapi2
             version = pysqlite3.dbapi2.version
             sqliteversion = pysqlite3.dbapi2.sqlite_version
-        except:
+        except Exception:
             version = False
         depend.append({
             'module': 'pysqlite2',
@@ -634,7 +634,7 @@ def get_dependencies():
     try:
         import psycopg2
         version = psycopg2.__version__
-    except:
+    except Exception:
         version = False
     optional.append({
         'module': 'psycopg2',
@@ -647,7 +647,7 @@ def get_dependencies():
         pymysql.install_as_MySQLdb()
         import MySQLdb
         version = '.'.join([str(i) for i in MySQLdb.version_info])
-    except:
+    except Exception:
         version = False
     optional.append({
         'module': 'MySQLdb',
@@ -658,7 +658,7 @@ def get_dependencies():
     try:
         import chardet
         version = chardet.__version__
-    except:
+    except Exception:
         version = False
     optional.append({
         'module': 'chardet',
@@ -668,7 +668,7 @@ def get_dependencies():
     try:
         import sqlite
         version = sqlite.version
-    except:
+    except Exception:
         version = False
     optional.append({
         'module': 'sqlite',
@@ -842,7 +842,7 @@ def get_image_fname(md5sum, gsql, size=None):
     file_name = os.path.join(gsql.data_dir, 'posters', md5sum + size + '.jpg')
 
     if not os.path.isfile(file_name) and not create_image_cache(md5sum, gsql):
-        log.warning(f"Can't create image file %s for md5sum %s" %
+        log.warning("Can't create image file %s for md5sum %s" %
                     (file_name, md5sum))
         return False
     return file_name
@@ -917,6 +917,7 @@ def define_logger_handler(logger_name):
     # logging.basicConfig(format='%(asctime)s: %(levelname).1s: %(name)s(%('
     #                            'module)s:%(lineno)d): %(message)s',
     #                     datefmt='%Y-%m-%dT%H:%M:%S')
+    Path(Path.home(), '.griffith').mkdir(parents=True, exist_ok=True)
     log_filepath = Path(Path.home(), '.griffith', 'griffith.log')
     logger = logging.getLogger(logger_name)
     file_handler = RotatingFileHandler(log_filepath, 'a', maxBytes=10_000_000, backupCount=2)
