@@ -608,7 +608,7 @@ class ExportPlugin(Base):
         self.search_conditions["sort_by"] = (sort_column,)
         query = self.get_query()
 
-        return query.execute()
+        return self.db.session.execute(query)
     #}}}
 
     #==[ main function ]============================{{{
