@@ -76,7 +76,7 @@ class ExportPlugin(Base):
                 return ''
             return val
 
-        movies = self.get_query().execute().fetchall()
+        movies = self.db.session.execute(self.get_query()).fetchall()
         for movie in movies:
             t.append("%s | %s | %s | %s" % (movie['number'], \
                 checkForNoneAndEncode(movie['o_title']),
@@ -113,6 +113,6 @@ class ExportPlugin(Base):
                         overwrite = True
                     else:
                         overwrite = False
-                if overwrite == True or overwrite is None:
+                if overwrite is True or overwrite is None:
                     shutil.copyfile(os.path.join(tmp_dir,"movies"), filename[0])
                     gutils.info(_("The list was successfully exported. Now you should move it to the 'Notes' folder on your iPod."), self.parent_window)
