@@ -13,8 +13,6 @@ __revision__ = '$Id$'
 import logging
 import os
 import re
-import string
-from functools import reduce
 from gettext import gettext as _
 
 from gi.repository import Gtk
@@ -29,7 +27,7 @@ def digits_only(s):
     _match = re.compile(r"\d+")
     try:
         s = ''.join(_match.findall(s))
-    except:
+    except Exception:
         s = '0'
     return s
 
@@ -38,7 +36,7 @@ def letters_only(s):
     _match = re.compile(r"\D+")
     try:
         s = ''.join(_match.findall(s))
-    except:
+    except Exception:
         s = str(s)
     return s
 
@@ -63,7 +61,7 @@ class ImportPlugin(IP):
             self.gtk = Gtk.Builder()
             self.gtk.set_translation_domain("griffith")
             self.gtk.add_from_file(gf)
-        except:
+        except Exception:
             log.info("Glade-file %s can not be loaded.", gf)
             return False
         # open gtk window
@@ -311,7 +309,7 @@ class ImportPlugin(IP):
                 iterator = self.ls_csv.append()
                 self.ls_csv.set_value(iterator, 0, name)
             return True
-        except:
+        except Exception:
             gutils.info(_("Can't open the file %s") % self.__source_name, self.gtk.get_object('d_import'))
             return False
 
@@ -334,7 +332,7 @@ class ImportPlugin(IP):
                     break
             detector.close()
             encoding = detector.result['encoding'].lower()
-        except:
+        except Exception:
             log.exception('')
             encoding = 'utf_8'
         encoding = self._encoding_cleanup.sub('', encoding)
@@ -369,7 +367,7 @@ class ImportPlugin(IP):
                     self.gtk.get_object('e_startrow').set_text('0')
             finally:
                 csvfile.close()
-        except:
+        except Exception:
             log.exception('')
         # run dialog
         response = self.gtk.get_object('d_import').run()
@@ -385,7 +383,7 @@ class ImportPlugin(IP):
             data = csv.reader(open(self.__source_name))
             while next(data):
                 i += 1
-        except:
+        except Exception:
             return i
 
     def get_movie_details(self):
@@ -394,7 +392,7 @@ class ImportPlugin(IP):
             # skip possible empty lines
             while not len(item):
                 item = next(self.data)
-        except:
+        except Exception:
             return None
         if item is None:
             return None
@@ -429,13 +427,13 @@ class ImportPlugin(IP):
                     try:
                         if item[int(self.import_table[field])].index(", ") != -1:
                             t_movies[field] = item[int(self.import_table[field])].replace(', ', "\n")
-                    except:
+                    except Exception:
                         t_movies[field] = item[int(self.import_table[field])].replace(',', "\n")
                     t_movies[field] = str(t_movies[field])
                 else:
                     # 1:1 import
                     t_movies[field] = str(item[int(self.import_table[field])])
-            except:
+            except Exception:
                 # error field can't be imported
                 log.exception("field %s cannot be imported", field)
                 t_movies.pop(field)
