@@ -57,7 +57,7 @@ class ImportPlugin(IP):
         IP.set_source(self, name)
         self.filename = name
         self.fileversion = self.read_fileversion()
-        if self.fileversion == None:
+        if self.fileversion is None:
             gutils.error(_('The format of the file is not supported.'))
             return False
         return True
@@ -69,7 +69,7 @@ class ImportPlugin(IP):
             try:
                 c = self.connection.execute('SELECT COUNT(*) FROM Main')
                 count = c.fetchone()[0]
-            except:
+            except Exception:
                 log.exception('')
         else:
             log.error('wintoolz Filmdatenbank: No connection object.')
@@ -151,13 +151,13 @@ class ImportPlugin(IP):
                     float(currentrow[20]) + float(currentrow[21]) + \
                     float(currentrow[22]) + float(currentrow[23]) + \
                     float(currentrow[24])), 0)
-            except:
+            except Exception:
                 pass
             if currentrow[25]:
                 details['seen'] = currentrow[25]
             if currentrow[26] and currentrow[26] == 'Schwarz-Weiss':
                 details['color'] = 2
-        except Exception as e:
+        except Exception:
             log.exception('')
             details = None
 
