@@ -33,7 +33,7 @@ import plugins.extensions
 try:
     from gi.repository import GtkSpell
     spell_support = 1
-except:
+except Exception:
     spell_support = 0
 
 log = logging.getLogger("Griffith")
@@ -42,73 +42,73 @@ log = logging.getLogger("Griffith")
 def show_preferences(self, page=None):
     w = self.widgets['preferences']
     # number
-    if self.config.get('number', True, section='mainlist') == False:
+    if self.config.get('number', True, section='mainlist') is False:
         w['view_number'].set_active(False)
     else:
         w['view_number'].set_active(True)
     # image
-    if self.config.get('image', True, section='mainlist') == False:
+    if self.config.get('image', True, section='mainlist') is False:
         w['view_image'].set_active(False)
     else:
         w['view_image'].set_active(True)
     # original title
-    if self.config.get('otitle', True, section='mainlist') == False:
+    if self.config.get('otitle', True, section='mainlist') is False:
         w['view_o_title'].set_active(False)
     else:
         w['view_o_title'].set_active(True)
     # title
-    if self.config.get('title', True, section='mainlist') == False:
+    if self.config.get('title', True, section='mainlist') is False:
         w['view_title'].set_active(False)
     else:
         w['view_title'].set_active(True)
     # director
-    if self.config.get('director', True, 'mainlist') == False:
+    if self.config.get('director', True, 'mainlist') is False:
         w['view_director'].set_active(False)
     else:
         w['view_director'].set_active(True)
     # genre
-    if self.config.get('genre', True, 'mainlist') == False:
+    if self.config.get('genre', True, 'mainlist') is False:
         w['view_genre'].set_active(False)
     else:
         w['view_genre'].set_active(True)
     # seen
-    if self.config.get('seen', True, 'mainlist') == False:
+    if self.config.get('seen', True, 'mainlist') is False:
         w['view_seen'].set_active(False)
     else:
         w['view_seen'].set_active(True)
     # year
-    if self.config.get('year', True, 'mainlist') == False:
+    if self.config.get('year', True, 'mainlist') is False:
         w['view_year'].set_active(False)
     else:
         w['view_year'].set_active(True)
     # runtime
-    if self.config.get('runtime', True, 'mainlist') == False:
+    if self.config.get('runtime', True, 'mainlist') is False:
         w['view_runtime'].set_active(False)
     else:
         w['view_runtime'].set_active(True)
     # rating
-    if self.config.get('rating', True, 'mainlist') == False:
+    if self.config.get('rating', True, 'mainlist') is False:
         w['view_rating'].set_active(False)
     else:
         w['view_rating'].set_active(True)
     # created
-    if self.config.get('created', True, 'mainlist') == False:
+    if self.config.get('created', True, 'mainlist') is False:
         w['view_created'].set_active(False)
     else:
         w['view_created'].set_active(True)
     # updated
-    if self.config.get('updated', True, 'mainlist') == False:
+    if self.config.get('updated', True, 'mainlist') is False:
         w['view_updated'].set_active(False)
     else:
         w['view_updated'].set_active(True)
 
     # email reminder
-    if self.config.get('use_auth', False, section='mail') == False:
+    if self.config.get('use_auth', False, section='mail') is False:
         w['mail_use_auth'].set_active(False)
     else:
         w['mail_use_auth'].set_active(True)
 
-    if self.config.get('mail_use_tls', False, section='mail') == False:
+    if self.config.get('mail_use_tls', False, section='mail') is False:
         w['mail_use_tls'].set_active(False)
     else:
         w['mail_use_tls'].set_active(True)
@@ -128,7 +128,7 @@ def show_preferences(self, page=None):
     if self.config.get('font_size'):
         try:
             w['font_size'].set_value(float(self.config.get('font_size')))
-        except:
+        except Exception:
             w['font_size'].set_value(18.0)
 
     # pdf elements
@@ -201,23 +201,23 @@ def show_preferences(self, page=None):
     # rating image
     try:
         rimage = int(self.config.get('rating_image', 0))
-    except:
+    except Exception:
         rimage = 0
     w['rating_image'].set_active(rimage)
 
     # spellchecker
-    if self.config.get('gtkspell', False, section='spell') == False:
+    if self.config.get('gtkspell', False, section='spell') is False:
         w['spellchecker'].set_active(False)
     else:
         w['spellchecker'].set_active(True)
     self.on_cb_spellchecker_pref_toggled(w['spellchecker'])
 
-    if self.config.get('notes', True, section='spell') == False:
+    if self.config.get('notes', True, section='spell') is False:
         w['spell_notes'].set_active(False)
     else:
         w['spell_notes'].set_active(True)
 
-    if self.config.get('plot', True, section='spell') == False:
+    if self.config.get('plot', True, section='spell') is False:
         w['spell_plot'].set_active(False)
     else:
         w['spell_plot'].set_active(True)
@@ -235,13 +235,13 @@ def save_preferences(self):
 
     was_false = notes_was_false = plot_was_false = 1
 
-    if c.get('gtkspell', False, section='spell') == True:
+    if c.get('gtkspell', False, section='spell') is True:
         was_false = 0
 
-    if c.get('notes', False, section='spell') == True:
+    if c.get('notes', False, section='spell') is True:
         notes_was_false = 0
 
-    if c.get('plot', False, section='spell') == True:
+    if c.get('plot', False, section='spell') is True:
         plot_was_false = 0
 
     # number
@@ -424,27 +424,27 @@ def save_preferences(self):
     c['pdf_reader'] = save_reader
 
     if spell_support:
-        if c.get('gtkspell', False, section='spell') == False and not was_false:
+        if c.get('gtkspell', False, section='spell') is False and not was_false:
             self.notes_spell.detach()
             self.plot_spell.detach()
-        elif c.get('gtkspell', False, section='spell') == True and was_false:
+        elif c.get('gtkspell', False, section='spell') is True and was_false:
             initialize.spellcheck(self)
         else:
             pass
 
-        if c.get('gtkspell', False, section='spell') == True:
-            if c.get('plot', True, section='spell') == False and not plot_was_false:
+        if c.get('gtkspell', False, section='spell') is True:
+            if c.get('plot', True, section='spell') is False and not plot_was_false:
                 self.plot_spell.detach()
-            elif c.get('plot', True, section='spell') == True and plot_was_false:
+            elif c.get('plot', True, section='spell') is True and plot_was_false:
                 self.plot_spell = GtkSpell.Checker.new()
                 self.plot_spell.set_language(c.get('lang', 'en', section='spell'))
                 self.plot_spell.attach(self.widgets['add']['plot'])
             else:
                 pass
 
-            if c.get('notes', True, section='spell') == False and not notes_was_false:
+            if c.get('notes', True, section='spell') is False and not notes_was_false:
                 self.notes_spell.detach()
-            elif c.get('notes', True, section='spell') == True and notes_was_false:
+            elif c.get('notes', True, section='spell') is True and notes_was_false:
                 self.notes_spell = GtkSpell.Checker.new()
                 self.notes_spell.set_language(c.get('lang', 'en', section='spell'))
                 self.notes_spell.attach(self.widgets['add']['notes'])
@@ -506,7 +506,7 @@ def save_preferences(self):
         try:
             self.db.dispose()
             self.db = sql.GriffithSQL(c, self.locations['home'], fallback=True)
-        except InvalidRequestError as e:
+        except InvalidRequestError:
             log.exception('')
             c.set('type', 'sqlite', section='database')
             w['db_type'].set_active(0)
