@@ -28,7 +28,8 @@ from gettext import gettext as _
 
 
 def define_widgets(self, gladefile):
-    get = lambda x: builder.get_object(x)
+    def get(x):
+        return builder.get_object(x)
     builder = Gtk.Builder()
     builder.set_translation_domain("griffith")
     builder.add_from_file(gladefile)
